summaryrefslogtreecommitdiffstats
path: root/third_party/aom/av1/common/av1_rtcd.c
diff options
context:
space:
mode:
Diffstat (limited to 'third_party/aom/av1/common/av1_rtcd.c')
-rw-r--r--third_party/aom/av1/common/av1_rtcd.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/third_party/aom/av1/common/av1_rtcd.c b/third_party/aom/av1/common/av1_rtcd.c
index 38e26bee1..a77a4d254 100644
--- a/third_party/aom/av1/common/av1_rtcd.c
+++ b/third_party/aom/av1/common/av1_rtcd.c
@@ -16,7 +16,7 @@
#include "aom_ports/aom_once.h"
void av1_rtcd() {
- // TODO(JBB): Remove this once, by insuring that both the encoder and
- // decoder setup functions are protected by once();
- once(setup_rtcd_internal);
+ // TODO(JBB): Remove this aom_once, by insuring that both the encoder and
+ // decoder setup functions are protected by aom_once();
+ aom_once(setup_rtcd_internal);
}